@@ -54,13 +54,12 @@ __END__
 
 Algorithm::Easing::Cubic - Calculate eased translations between two positive whole integer values over time
 
-=back
 =head1 SYNOPSIS
 
         ## with mediator
 
         use Algorithm::Easing;
-        use Algorithm::Easing::Cubic;
+        use Algorithm::Easing::Ease;
 
         # this example produces traditional 'cubic' output;
 
@@ -87,7 +86,29 @@ Algorithm::Easing::Cubic - Calculate eased translations between two positive who
             ...;
         }
 
+=head1 INTRODUCTION
+
+Commonly used in animation, Penner's easing functions are beautiful translations between two positive whole integer values.
+
+The included easing functions in Algorithm::Easing are :
+
+=over
+=item Exponential
+=item Elastic
+=item Bounce
+=item Linear
+=item Cubic
+=item Quadratic
+=item Quartinion
+=item Quintonion
+=item Sinusoidal
+=item Backdraft
+=item Circular
 =back
+
+For ease of use, there is an included Mediator class.  The Mediator class permits the programmer to select from the spread of easing functions through a single class name.
+
+=over
 =item ease_none
     Usage :
     
@@ -103,8 +124,6 @@ Algorithm::Easing::Cubic - Calculate eased translations between two positive who
 
 This method is used for a linear translation between two positive real whole integers using a positive real integer as the parameter for time.
 
-=back
-=over 2
 =item ease_in
     Usage :
     
@@ -120,8 +139,6 @@ This method is used for a linear translation between two positive real whole int
 
 This method is used for a eased translation between two positive real whole integers as an inward tween using a positive real integer as the parameter for time.
 
-=back
-=over 2
 =item ease_out
     Usage :
     
@@ -137,8 +154,6 @@ This method is used for a eased translation between two positive real whole inte
 
 This method is used for a eased translation between two positive real whole integers as an outward tween using a positive real integer as the parameter for time.
 
-=back
-=over 2
 =item ease_both
     Usage :
     
@@ -154,11 +169,11 @@ This method is used for a eased translation between two positive real whole inte
 
 This method is used for a eased translation between two positive real whole integers as an inward then outward tween using a positive real integer as the parameter for time.
 
+=back
 =head1 AUTHOR
 
 Jason McVeigh, <jmcveigh@outlook.com>
 
-=back
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2016 by Jason McVeigh
